Functions
- refs_
from - Run
refs from <page>: list all pages the given page links to. - refs_
graph - Run
refs graph: dump the full link graph. - refs_to
- Run
refs to <page>: list all pages that link to the given page.
refs from <page>: list all pages the given page links to.refs graph: dump the full link graph.refs to <page>: list all pages that link to the given page.