Structs
- Classified
Range - A byte range within the source classified by its structural role.
Enums
- Range
Kind - Classification of a byte range within a markdown source.
Functions
- classify_
ranges - Classify every emitted byte range in the source by structural role.
- extract_
block_ ids - Extract block IDs (lines like
^block-id) from the source. - extract_
headings - Extract all headings from the source.
- extract_
wikilinks - Extract all wikilink occurrences from the source.