Module parse

Module parse 

Structs

ClassifiedRange
A byte range within the source classified by its structural role.

Enums

RangeKind
Classification of a byte range within a markdown source.

Functions

classify_ranges
Classify every emitted byte range in the source by structural role.
extract_block_ids
Extract block IDs (lines like ^block-id) from the source.
extract_headings
Extract all headings from the source.
extract_wikilinks
Extract all wikilink occurrences from the source.