Wiki

Struct Wiki 

pub struct Wiki { /* private fields */ }
Unified wiki structure with lazy-loaded content caching.

Implementations

Source

impl Wiki

pub fn build(root: WikiRoot, config: WikiConfig) -> Result<Self, WikiError>

Build wiki from root — discovers paths only, no file reads.

pub fn root(&self) -> &WikiRoot

pub fn config(&self) -> &WikiConfig

pub fn pages(&self) -> &HashMap<PageId, PageEntry>

pub fn get(&self, id: &PageId) -> Option<&PageEntry>

pub fn contains(&self, id: &PageId) -> bool

pub fn find(&self, name: &str) -> Option<(&PageId, &PageEntry)>

Find a page by name. Always O(1) since PageIds are normalized to lowercase.

pub fn display_name(&self, id: &PageId) -> Option<&str>

Get the display name for a page (original filename case from rel_path).

pub fn index_path(&self) -> Option<PathBuf>

pub fn entry_path(&self, entry: &PageEntry) -> PathBuf

Get the absolute path for a page entry.

pub fn rel_path<'a>(&self, path: &'a Path) -> &'a Path

Convert an absolute path to a path relative to the wiki root.

pub fn all_scannable_files(&self) -> Vec<PathBuf>

All wiki page files that should be scanned for wikilink content.

Autolink pages — lazily computed on first access.

pub fn abs_path(&self, path: &Path) -> PathBuf

pub fn file(&self, path: &Path) -> Result<&CachedFile, WikiError>

Get cached file, loading on first access.

pub fn source(&self, path: &Path) -> Result<&str, WikiError>

Get source content for a file.

pub fn frontmatter( &self, path: &Path, ) -> Result<&Result<Option<Frontmatter>, FrontmatterError>, WikiError>

Get frontmatter for a file.

pub fn headings(&self, path: &Path) -> Result<&[Heading], WikiError>

Get headings for a file.

Get wikilinks for a file.

pub fn classified_ranges( &self, path: &Path, ) -> Result<&[ClassifiedRange], WikiError>

Get classified ranges for a file.

pub fn block_ids(&self, path: &Path) -> Result<&[BlockId], WikiError>

Get block IDs for a file.

pub fn write_file( &mut self, path: &Path, content: &str, ) -> Result<(), WikiError>

Write file content. Takes &mut self to ensure no outstanding borrows.

pub fn rename_file(&mut self, old: &Path, new: &Path) -> Result<(), WikiError>

Rename a file. Takes &mut self to ensure no outstanding borrows.